@@ -12,7 +12,7 @@ Stencils: [optional] folder from where project can find visio stencils.
 
 """
 
-__ver__ = "0.0.8"
+__ver__ = "0.0.9"
 
 # ------------------------------------------------------------------------------
 
@@ -27,6 +27,6 @@ from .devices import AdevDevices
 from .cablings import ADevCablings
 from .general import get_physical_if_up, get_physical_if_relevants
 from .general import get_patterns, update_pattern
-from .pyVig import pyVig
+from .pyVig import pyVig, pyVig_gui
 # ------------------------------------------------------------------------------
 
